@@ -394,7 +394,6 @@ class LatestTleSetSerializer(serializers.ModelSerializer):
                 'norad_cat_id': 40379,
                 'transmitter': None,
                 'app_source': 'network',
-                'schema': None,
                 'decoded': 'influxdb',
                 'frame': '968870A6A0A66086A240404040E103F0ABCD0000004203F500B475E215EA5FA0040C000B'
                 '000900010025008E55EE7B64650100000000AE4D07005D660F007673340000C522370067076507FD0'
@@ -415,7 +414,6 @@ class TelemetrySerializer(serializers.ModelSerializer):
     sat_id = serializers.SerializerMethodField()
     norad_cat_id = serializers.SerializerMethodField()
     transmitter = serializers.SerializerMethodField()
-    schema = serializers.SerializerMethodField()
     decoded = serializers.SerializerMethodField()
     frame = serializers.SerializerMethodField()
     associated_satellites = serializers.SerializerMethodField()
@@ -423,9 +421,8 @@ class TelemetrySerializer(serializers.ModelSerializer):
     class Meta:
         model = DemodData
         fields = (
-            'sat_id', 'norad_cat_id', 'transmitter', 'app_source', 'schema', 'decoded', 'frame',
-            'observer', 'timestamp', 'version', 'observation_id', 'station_id',
-            'associated_satellites'
+            'sat_id', 'norad_cat_id', 'transmitter', 'app_source', 'decoded', 'frame', 'observer',
+            'timestamp', 'version', 'observation_id', 'station_id', 'associated_satellites'
         )
 
     @extend_schema_field(OpenApiTypes.STR)
@@ -448,15 +445,6 @@ class TelemetrySerializer(serializers.ModelSerializer):
         except AttributeError:
             return ''
 
-    # deprecated, needs pulled out - cshields
-    @extend_schema_field(OpenApiTypes.STR)
-    def get_schema(self, obj):
-        """Returns Transmitter telemetry schema"""
-        try:
-            return obj.payload_telemetry.schema
-        except AttributeError:
-            return ''
-
     @extend_schema_field(OpenApiTypes.STR)
     def get_decoded(self, obj):
         """Returns the payload_decoded field"""
