@@ -235,19 +235,24 @@ class LoginView(TestCase):
     datum = None
 
     def setUp(self):
-        # pagination is set to 25 per page
         DemodDataFactory.create_batch(size=18)
         self.datum = DemodDataFactory()
         self.datum.save()
         self.client.force_login(User.objects.get_or_create(username='testuser')[0])
 
-    def test_auth_telemetry_list_pg1(self):
+    def test_auth_telemetry_list_without_filter(self):
         """Test the Telemetry API listing and pagination with authentication"""
         response = self.client.get('/api/telemetry/?page=1')
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+
+    def test_auth_telemetry_list_with_satellite_filter(self):
+        """Test the Telemetry API listing and pagination with authentication"""
+        norad_id = self.datum.satellite.satellite_entry.norad_cat_id
+        response = self.client.get('/api/telemetry/?page=1&satellite=' + str(norad_id))
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-    def test_auth_telemetry_list_pg2(self):
+    def test_auth_telemetry_list_with_sat_id_filter(self):
         """Test the Telemetry API listing and pagination with authentication"""
-        DemodDataFactory.create_batch(size=25)
-        response = self.client.get('/api/telemetry/?page=2&format=json')
+        sat_id = self.datum.satellite.satellite_identifier.sat_id
+        response = self.client.get('/api/telemetry/?page=1&sat_id=' + sat_id)
         self.assertEqual(response.status_code, status.HTTP_200_OK)
