@@ -278,6 +278,15 @@ class Satellite(models.Model):
         transmitters = Transmitter.objects.filter(satellite=self.id).exclude(status='invalid')
         return transmitters
 
+    @property
+    def invalid_transmitters(self):
+        """Returns invalid transmitters for this Satellite
+
+        :returns: the invalid transmitters for this Satellite
+        """
+        transmitters = Transmitter.objects.filter(satellite=self.id).filter(status='invalid')
+        return transmitters
+
     @property
     def transmitter_suggestion_count(self):
         """Returns number of pending transmitter suggestions for this Satellite
@@ -709,7 +718,6 @@ class Telemetry(models.Model):
         Satellite, null=True, related_name='telemetries', on_delete=models.SET_NULL
     )
     name = models.CharField(max_length=45)
-    schema = models.TextField(blank=True)
     decoder = models.CharField(max_length=200, blank=True)
 
     class Meta:
