@@ -95,11 +95,11 @@ def transmitters_list(request):
     """
     transmitters = Transmitter.objects.filter(
         satellite__associated_satellite__isnull=True, satellite__satellite_entry__approved=True
-    ).exclude(
-        status='invalid'
     ).select_related('satellite', 'satellite__satellite_entry', 'satellite__satellite_identifier')
 
-    return render(request, 'base/transmitters.html', {'transmitters': transmitters})
+    return render(request, 'base/transmitters.html', {
+        'transmitters': transmitters,
+    })
 
 
 def robots(request):
@@ -149,6 +149,7 @@ def satellite(request, norad=None, sat_id=None):
 
     latest_tle = None
     latest_tle_set = None
+    latest_tle_warning = None
     if hasattr(satellite_obj, 'latest_tle_set'):
         latest_tle_set = satellite_obj.latest_tle_set
 
@@ -157,6 +158,8 @@ def satellite(request, norad=None, sat_id=None):
             latest_tle = latest_tle_set.latest
         else:
             latest_tle = latest_tle_set.latest_distributable
+            if latest_tle_set.latest != latest_tle_set.latest_distributable:
+                latest_tle_warning = "There is at least one newer non-redestributable TLE set."
 
     transmitter_suggestions = TransmitterSuggestion.objects.filter(satellite=satellite_obj)
     for suggestion in transmitter_suggestions:
@@ -194,7 +197,8 @@ def satellite(request, norad=None, sat_id=None):
             'mapbox_token': settings.MAPBOX_TOKEN,
             'recent_observers': recent_observers,
             'badge_telemetry_count': millify(satellite_obj.telemetry_data_count),
-            'showmap': showmap
+            'showmap': showmap,
+            "latest_tle_warning": latest_tle_warning
         }
     )
 
@@ -327,7 +331,7 @@ def search(request):
                 queryset=Transmitter.objects.all(),
                 to_attr='approved_transmitters'
             )
-        )
+        ).distinct()
 
     if results.count() == 1:
         return redirect(
