@@ -52,7 +52,7 @@ def setup_periodic_tasks(sender, **kwargs):
     sender.add_periodic_task(RUN_EVERY_TWO_HOURS, update_tle_sets.s(), name='update-tle-sets')
 
     sender.add_periodic_task(
-        RUN_HOURLY, background_cache_statistics.s(), name='background-cache-statistics'
+        RUN_DAILY, background_cache_statistics.s(), name='background-cache-statistics'
     )
 
     sender.add_periodic_task(
