@@ -69,17 +69,25 @@ function transmitter_suggestion_type(selection) {
 }
 
 $(function () {
-    // Initialize ITU Coordination URLs textarea and hide the JSON one
-    $('textarea[name=\'itu_coordination\']').prop('readonly', true);
+    // Initialize ITU Notifications URLs textarea and hide the JSON one
+    $('textarea[name=\'itu_notification\']').prop('readonly', true);
     $('#itu-coordination-input-group').hide();
-    var itu_urls = $.parseJSON($('textarea[name=\'itu_coordination\']').val())['urls'];
-    $('textarea[name=\'itu_coordination_per_line\']').val(itu_urls.join('\n'));
-    // Add event for changing JSON textarea when ITU Coordination URLs changes
-    $('textarea[name=\'itu_coordination_per_line\']').on('change click', function(){
-        var itu_coordination_json = $.parseJSON($('textarea[name=\'itu_coordination\']').val());
-        var new_itu_urls = $('textarea[name=\'itu_coordination_per_line\']').val().split('\n');
-        itu_coordination_json['urls'] = new_itu_urls;
-        $('textarea[name=\'itu_coordination\']').val(JSON.stringify(itu_coordination_json));
+    var itu_urls = $.parseJSON($('textarea[name=\'itu_notification\']').val())['urls'];
+    $('textarea[name=\'itu_notification_per_line\']').val(itu_urls.join('\n'));
+    // Add event for changing JSON textarea when ITU Notifications URLs changes
+    $('textarea[name=\'itu_notification_per_line\']').on('change click', function(){
+        var itu_notification_json = $.parseJSON($('textarea[name=\'itu_notification\']').val());
+        var new_itu_urls = $('textarea[name=\'itu_notification_per_line\']').val().split('\n');
+        // Trim all entries and remove the empty ones
+        new_itu_urls = new_itu_urls.map(function(url){
+            return url.trim();
+        }).filter(function (url){
+            if (url.length !=0){
+                return true;
+            }
+        });
+        itu_notification_json['urls'] = new_itu_urls;
+        $('textarea[name=\'itu_notification\']').val(JSON.stringify(itu_notification_json));
     });
     // Initialize frequency drift fields and their events
     $('input[name=\'uplink_drift\']').prop('readonly', true);
